==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Visionneuse d&apos;images</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Image Viewer est un visualiseur d&apos;images moderne et performant.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>images </translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informations de l&apos;image</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Entrée</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Entrée</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Informations de base</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Ce fichier contient plusieurs pages, merci d&apos;utiliser Evince pour visualiser toutes les pages.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Ouvrir le dossier</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Vous n&apos;avez pas l&apos;autorisation de voir cette image</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Fichier image non trouvé</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Genre</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Date de modification</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Dimension</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Taille du fichier</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Date de capture</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mode d&apos;exposition</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Mode d&apos;exposition</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Temps d&apos;exposition</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash </translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Ouverture</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Distance focale</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO </translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Ouverture Max</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mode de mesure</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balance des blancs</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensation du flash</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modèle de lentille</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espace chromatique</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modèle d&apos;appareil photo</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensions</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Pas de mise à l&apos;échelle</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Adapter la page à l&apos;image</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Ajuster l&apos;image à la page</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Échelle jusqu&apos;à :</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Millimètres</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centimètres</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Pouces</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Position de l&apos;image</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Mise à l&apos;échelle</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Paramètres d&apos;image</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Paramètres d&apos;image</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Stores</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Basculer</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Glisser</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Cercle</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>yyyy/MM/dd HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Entrer un nouveau nom</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Sélectionner dossier</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Ce répertoire est désactivé pour la synchronisation</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Ajouter un dossier</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Dossier à synchroniser </translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>La liste de dossier est vide</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Annuler la synchronisation </translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Images </translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Le périphérique a été enlevé</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Ce dossier n&apos;existe plus</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Calcul en cours...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visionneuse d&apos;image</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album </translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres </translation>
    </message>
    <message>
        <source>View</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Fin du diaporama</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Enlever de l&apos;album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoris </translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Retirer des favoris</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotation droite</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotation gauche</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Définir comme fond d&apos;écran</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Afficher dans le gestionnaire de fichier</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Image infos</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Précédent </translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Écran précédent </translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Écran suivant</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nouvel Album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer </translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afficher les raccourcis</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Quitter le mode plein écran</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Agrandir</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Réduire</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Créer un nouveau raccourci</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Afficher l&apos;image</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album </translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Paramètres par défaut</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Fin du diaporama</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Enlever de l&apos;album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoris </translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Retirer des favoris</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotation droite</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotation gauche</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Définir comme fond d&apos;écran</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Afficher dans le gestionnaire de fichier</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Image infos</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nouvel Album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer </translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Précédent </translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Paramètres de défilement</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Effet de transition</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Durée de transition</translation>
    </message>
    <message>
        <source>second</source>
        <translation>secondes</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>Mon favori</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Précédent </translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Taille 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajuster à la fenêtre</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotation dans le sens antihoraire</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotation dans le sens horaire</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Retour</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Gestionnaire d&apos;image</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mes favoris </translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Taille 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajuster à la fenêtre</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Tourner dans le sens inverse des aiguilles d&apos;une montre</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Tourner dans le sens des aiguilles d&apos;une montre</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Retirer des favoris</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoris </translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Pas d&apos;images trouvées</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Ouvrir une image</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Fichier image introuvable</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Paramètres de défilement</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Effet </translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album </translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Nouvel Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres </translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Chronologie</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Ajouter à l&apos;album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Ajouter à un nouvel album</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Quitter le plein écran</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Enlever de l&apos;album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoris </translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Retirer des favoris</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Afficher la fenêtre de navigation</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Cacher la fenêtre de navigation</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotation droite</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotation gauche</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Définir comme fond d&apos;écran</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Afficher dans le gestionnaire de fichier</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informations sur l&apos;image</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Ouvrir une image</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Toutes les images </translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer </translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Dessin</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.6.orig.tar.xz: deepin-image-viewer-5.9.6/src/translations/deepin-image-viewer_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>Fichier image non trouvé</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Ouvrir une image</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visionneuse d&apos;image</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres </translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Quitter le mode plein écran</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extraire du texte</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer </translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotation dans le sens horaire</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotation dans le sens antihoraire</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Définir comme fond d&apos;écran</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Afficher dans le gestionnaire de fichier</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informations de l&apos;image</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Précédent </translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Agrandir</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Réduire</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afficher les raccourcis</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Visionneuse d&apos;images</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Image Viewer est un visualiseur d&apos;images moderne et performant.</translation>
    </message>
</context>
</TS>
